Range-v3: ranges::v3::concepts::RandomAccessIterator Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::concepts::RandomAccessIterator Struct Reference
Inheritance diagram for ranges::v3::concepts::RandomAccessIterator:

## Public Member Functions
template<typename I >
auto | requires_ (I i) -> decltype(concepts::valid_expr(concepts::model_of< DerivedFrom, category_t< I >, ranges::random_access_iterator_tag >(), concepts::has_type< I >(i+(i - i)), concepts::has_type< I >((i - i)+i), concepts::has_type< I >(i -(i - i)), concepts::has_type< I &>(i+=(i-i)), concepts::has_type< I &>(i -=(i - i)), concepts::model_of< Same, reference_t< I >, decltype(i[i - i])>()))
Public Member Functions inherited from ranges::v3::concepts::refines< BidirectionalIterator, TotallyOrdered, SizedSentinel(_1, _1)>
void | requires_ ()

## Additional Inherited Members
Public Types inherited from ranges::v3::concepts::refines< BidirectionalIterator, TotallyOrdered, SizedSentinel(_1, _1)>
using | base_concepts_t = meta::list< Concepts... >